<div class="panel panel-default">
    <div class="panel-heading">
        {{ widget.title }}
        {% comment %}
        <a href="#" class="pull-right">
            <i class="fa fa-refresh"></i>
        </a>
        {% endcomment %}
    </div>
    <div class="panel-body">
        <h1>
            <strong>{{ widget.count }}</strong> {{ widget.label }}
        </h1>
    </div>
</div>
